@@ -1,20 +1,23 @@
 package App::GitGot::Command;
+$App::GitGot::Command::VERSION = '1.20';
 # ABSTRACT: Base class for App::GitGot commands
-$App::GitGot::Command::VERSION = '1.19';
 use Mouse;
 extends 'MouseX::App::Cmd::Command';
 use 5.010;
+use namespace::autoclean;
 
 use App::GitGot::Repo::Git;
+use App::GitGot::Repositories;
+
+use Cwd;
 use File::Path 2.08         qw/ make_path /;
-use List::Util              qw/ max /;
+use List::AllUtils          qw/ max first /;
 use Path::Class;
 use Try::Tiny;
 use YAML                    qw/ DumpFile LoadFile /;
-use namespace::autoclean;
 
 # option attrs
-has 'all' => (
+has all => (
   is            => 'rw',
   isa           => 'Bool',
   documentation => 'use all available repositories' ,
@@ -22,14 +25,14 @@ has 'all' => (
   traits        => [qw/ Getopt /],
 );
 
-has 'by_path' => (
+has by_path => (
   is          => 'rw' ,
   isa         => 'Bool' ,
   cmd_aliases => 'p',
   traits      => [qw/ Getopt /],
 );
 
-has 'color_scheme' => (
+has color_scheme => (
   is            => 'rw',
   isa           => 'Str',
   documentation => 'name of color scheme to use',
@@ -38,7 +41,7 @@ has 'color_scheme' => (
   traits        => [qw/ Getopt /],
 );
 
-has 'configfile' => (
+has configfile => (
   is            => 'rw',
   isa           => 'Str',
   documentation => 'path to config file',
@@ -48,7 +51,7 @@ has 'configfile' => (
   required      => 1,
 );
 
-has 'no_color' => (
+has no_color => (
   is            => 'rw',
   isa           => 'Bool',
   documentation => 'do not use colored output',
@@ -57,7 +60,7 @@ has 'no_color' => (
   traits        => [qw/ Getopt /],
 );
 
-has 'quiet' => (
+has quiet => (
   is            => 'rw',
   isa           => 'Bool',
   documentation => 'keep it down',
@@ -65,15 +68,7 @@ has 'quiet' => (
   traits        => [qw/ Getopt /],
 );
 
-has 'tags' => (
-  is            => 'rw',
-  isa           => 'ArrayRef[Str]',
-  documentation => 'select repositories tagged with these words' ,
-  cmd_aliases   => 't',
-  traits        => [qw/ Getopt /],
-);
-
-has 'skip_tags' => (
+has skip_tags => (
   is            => 'rw',
   isa           => 'ArrayRef[Str]',
   documentation => 'select repositories not tagged with these words' ,
@@ -81,7 +76,15 @@ has 'skip_tags' => (
   traits        => [qw/ Getopt /],
 );
 
-has 'verbose' => (
+has tags => (
+  is            => 'rw',
+  isa           => 'ArrayRef[Str]',
+  documentation => 'select repositories tagged with these words' ,
+  cmd_aliases   => 't',
+  traits        => [qw/ Getopt /],
+);
+
+has verbose => (
   is            => 'rw',
   isa           => 'Bool',
   documentation => 'bring th\' noise',
@@ -90,7 +93,7 @@ has 'verbose' => (
 );
 
 # non-option attrs
-has 'active_repo_list' => (
+has active_repo_list => (
   is         => 'rw',
   isa        => 'ArrayRef[App::GitGot::Repo::Git]' ,
   traits     => [qw/ NoGetopt Array /],
@@ -100,13 +103,13 @@ has 'active_repo_list' => (
   } ,
 );
 
-has 'args' => (
+has args => (
   is     => 'rw' ,
   isa    => 'ArrayRef' ,
   traits => [ qw/ NoGetopt / ] ,
 );
 
-has 'full_repo_list' => (
+has full_repo_list => (
   is         => 'rw',
   isa        => 'ArrayRef[App::GitGot::Repo::Git]' ,
   traits     => [qw/ NoGetopt Array /],
@@ -117,7 +120,7 @@ has 'full_repo_list' => (
   } ,
 );
 
-has 'outputter' => (
+has outputter => (
   is         => 'ro' ,
   isa        => 'App::GitGot::Outputter' ,
   traits     => [ qw/ NoGetopt / ] ,
@@ -146,6 +149,15 @@ sub execute {
 }
 
 
+sub local_repo {
+  my $self = shift;
+
+  my $dir = $self->_find_repo_root( getcwd() );
+
+  return first { $_->path eq $dir->absolute } $self->all_repos;
+}
+
+
 sub max_length_of_an_active_repo_label {
   my( $self ) = @_;
 
@@ -163,6 +175,15 @@ sub prompt_yn {
 }
 
 
+sub search_repos {
+  my $self = shift;
+
+  return App::GitGot::Repositories->new(
+    repos => [ $self->all_repos ]
+  );
+}
+
+
 sub write_config {
   my ($self) = @_;
 
@@ -277,50 +298,46 @@ sub _expand_arg_list {
   ## use critic
 }
 
-sub _git_status {
-  my ( $self, $entry ) = @_
-    or die "Need entry";
+sub _fetch {
+  my( $self , @repos ) = @_;
 
-  my( $msg , $verbose_msg ) = $self->_run_git_status( $entry );
+  my $max_len = $self->max_length_of_an_active_repo_label;
 
-  $msg .= $self->_run_git_cherry( $entry )
-    if $entry->current_remote_branch;
+ REPO: for my $repo ( @repos ) {
+    next REPO unless $repo->repo;
 
-  return ( $self->verbose ) ? "$msg$verbose_msg" : $msg;
+    my $name = $repo->name;
+
+    my $msg = sprintf "%3d) %-${max_len}s  : ", $repo->number, $repo->label;
+
+    my ( $status, $fxn );
+
+    my $repo_type = $repo->type;
+
+    if ( $repo_type eq 'git' ) { $fxn = '_git_fetch' }
+    ### FIXME elsif( $repo_type eq 'svn' ) { $fxn = 'svn_update' }
+    else { $status = $self->error("ERROR: repo type '$_' not supported") }
+
+    $status = $self->$fxn($repo) if ($fxn);
+
+    next REPO if $self->quiet and !$status;
+
+    say "$msg$status";
+  }
 }
 
-sub _git_update {
-  my ( $self, $entry ) = @_
-    or die "Need entry";
+sub _find_repo_root {
+  my( $self , $path ) = @_;
 
-  my $msg = '';
+  my $dir = dir( $path );
 
-  my $path = $entry->path;
-
-  if ( !-d $path ) {
-    make_path $path;
-
-    try {
-      $entry->clone( $entry->repo , './' );
-      $msg .= $self->major_change('Checked out');
-    }
-    catch { $msg .= $self->error('ERROR') . "\n$_" };
-  }
-  elsif ( -d "$path/.git" ) {
-    try {
-      my @o = $entry->pull;
-      if ( $o[0] eq 'Already up-to-date.' ) {
-        $msg .= $self->minor_change('Up to date') unless $self->quiet;
-      }
-      else {
-        $msg .= $self->major_change('Updated');
-        $msg .= "\n" . join("\n",@o) unless $self->quiet;
-      }
-    }
-    catch { $msg .= $self->error('ERROR') . "\n$_" };
+  # find repo root
+  while ( ! grep { -d and $_->basename eq '.git' } $dir->children ) {
+    die "$path doesn't seem to be in a git directory\n" if $dir eq $dir->parent;
+    $dir = $dir->parent;
   }
 
-  return $msg;
+  return $dir
 }
 
 sub _git_fetch {
@@ -375,6 +392,86 @@ sub _git_fetch {
   return $msg;
 }
 
+sub _git_status {
+  my ( $self, $entry ) = @_
+    or die "Need entry";
+
+  my( $msg , $verbose_msg ) = $self->_run_git_status( $entry );
+
+  $msg .= $self->_run_git_cherry( $entry )
+    if $entry->current_remote_branch;
+
+  return ( $self->verbose ) ? "$msg$verbose_msg" : $msg;
+}
+
+sub _git_update {
+  my ( $self, $entry ) = @_
+    or die "Need entry";
+
+  my $msg = '';
+
+  my $path = $entry->path;
+
+  if ( !-d $path ) {
+    make_path $path;
+
+    try {
+      $entry->clone( $entry->repo , './' );
+      $msg .= $self->major_change('Checked out');
+    }
+    catch { $msg .= $self->error('ERROR') . "\n$_" };
+  }
+  elsif ( -d "$path/.git" ) {
+    try {
+      my @o = $entry->pull;
+      if ( $o[0] eq 'Already up-to-date.' ) {
+        $msg .= $self->minor_change('Up to date') unless $self->quiet;
+      }
+      else {
+        $msg .= $self->major_change('Updated');
+        $msg .= "\n" . join("\n",@o) unless $self->quiet;
+      }
+    }
+    catch { $msg .= $self->error('ERROR') . "\n$_" };
+  }
+
+  return $msg;
+}
+
+sub _path_is_managed {
+  my( $self , $path ) = @_;
+
+  return unless $path;
+
+  my $dir     = $self->_find_repo_root( $path );
+  my $max_len = $self->max_length_of_an_active_repo_label;
+
+  for my $repo ( $self->active_repos ) {
+    next unless $repo->path eq $dir->absolute;
+
+    my $repo_remote = ( $repo->repo and -d $repo->path ) ? $repo->repo
+      : ( $repo->repo )    ? $repo->repo . ' (Not checked out)'
+      : ( -d $repo->path ) ? 'NO REMOTE'
+      : 'ERROR: No remote and no repo?!';
+
+    printf "%3d) ", $repo->number;
+
+    if ( $self->quiet ) { say $repo->label }
+    else {
+      printf "%-${max_len}s  %-4s  %s\n",
+        $repo->label, $repo->type, $repo_remote;
+      if ( $self->verbose ) {
+        printf "    tags: %s\n" , $repo->tags if $repo->tags;
+      }
+    }
+
+    return 1;
+  }
+
+  say "repository not in Got list";
+  return;
+}
+
 sub _read_config {
   my $file = shift;
 
@@ -402,7 +499,7 @@ sub _run_git_cherry {
       }
     }
   }
-    catch { $msg = $self->error('ERROR') . "\n$_" };
+  catch { $msg = $self->error('ERROR') . "\n$_" };
 
   return $msg
 }
@@ -440,7 +537,7 @@ sub _run_git_status {
       $verbose_msg = "\n$verbose_msg" if $verbose_msg;
     }
   }
-    catch { $msg .= $self->error('ERROR') . "\n$_" };
+  catch { $msg .= $self->error('ERROR') . "\n$_" };
 
   return( $msg , $verbose_msg );
 }
@@ -502,76 +599,6 @@ sub _update {
   }
 }
 
-sub _fetch {
-  my( $self , @repos ) = @_;
-
-  my $max_len = $self->max_length_of_an_active_repo_label;
-
- REPO: for my $repo ( @repos ) {
-    next REPO unless $repo->repo;
-
-    my $name = $repo->name;
-
-    my $msg = sprintf "%3d) %-${max_len}s  : ", $repo->number, $repo->label;
-
-    my ( $status, $fxn );
-
-    my $repo_type = $repo->type;
-
-    if ( $repo_type eq 'git' ) { $fxn = '_git_fetch' }
-    ### FIXME elsif( $repo_type eq 'svn' ) { $fxn = 'svn_update' }
-    else { $status = $self->error("ERROR: repo type '$_' not supported") }
-
-    $status = $self->$fxn($repo) if ($fxn);
-
-    next REPO if $self->quiet and !$status;
-
-    say "$msg$status";
-  }
-}
-
-
-sub _path_is_managed {
-  my( $self , $path ) = @_;
-
-  return unless $path;
-
-  my $dir = dir( $path );
-
-  # find repo root
-  while ( ! grep { -d and $_->basename eq '.git' } $dir->children ) {
-    die "$path doesn't seem to be in a git directory\n" if $dir eq $dir->parent;
-    $dir = $dir->parent;
-  }
-
-  my $max_len = $self->max_length_of_an_active_repo_label;
-
-  for my $repo ( $self->active_repos ) {
-    next unless $repo->path eq $dir->absolute;
-
-    my $repo_remote = ( $repo->repo and -d $repo->path ) ? $repo->repo
-      : ( $repo->repo )    ? $repo->repo . ' (Not checked out)'
-      : ( -d $repo->path ) ? 'NO REMOTE'
-      : 'ERROR: No remote and no repo?!';
-
-    printf "%3d) ", $repo->number;
-
-    if ( $self->quiet ) { say $repo->label }
-    else {
-      printf "%-${max_len}s  %-4s  %s\n",
-        $repo->label, $repo->type, $repo_remote;
-      if ( $self->verbose ) {
-        printf "    tags: %s\n" , $repo->tags if $repo->tags;
-      }
-    }
-
-    return 1;
-  }
-
-  say "repository not in Got list";
-  return;
-}
-
 # override this in commands that shouldn't use IO::Page -- i.e., ones that
 # need to do incremental output
 sub _use_io_page { 1 }
@@ -591,10 +618,15 @@ App::GitGot::Command - Base class for App::GitGot commands
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 METHODS
 
+=head2 local_repo
+
+Checks to see if $CWD is inside a Git repo managed by Got, and returns the
+corresponding L<App::GitGot::Repo> object if it is.
+
 =head2 max_length_of_an_active_repo_label
 
 Returns the length of the longest name in the active repo list.
@@ -605,6 +637,11 @@ Takes a message argument and uses it to prompt for a yes/no response.
 
 Response defaults to 'no'.
 
+=head2 search_repos
+
+Returns a L<App::GotGot::Repositories> object containing all repos managed by
+Got.
+
 =head2 write_config
 
 Dumps configuration out to disk.
