@@ -1,9 +1,10 @@
 package App::GitGot::Command::clone;
+$App::GitGot::Command::clone::VERSION = '1.20';
 # ABSTRACT: clone a remote repo and add it to your config
-$App::GitGot::Command::clone::VERSION = '1.19';
 use Mouse;
 extends 'App::GitGot::Command';
 use 5.010;
+use namespace::autoclean;
 
 use App::GitGot::Repo::Git;
 use Cwd;
@@ -11,7 +12,7 @@ use File::Basename;
 use File::Spec;
 use Term::ReadLine;
 
-has 'defaults' => (
+has defaults => (
   is          => 'rw',
   isa         => 'Bool',
   cmd_aliases => 'D',
@@ -72,7 +73,7 @@ App::GitGot::Command::clone - clone a remote repo and add it to your config
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 AUTHOR
 
