@@ -1,9 +1,10 @@
 package App::GitGot::Command::fork;
+$App::GitGot::Command::fork::VERSION = '1.20';
 # ABSTRACT: fork a github repo
-$App::GitGot::Command::fork::VERSION = '1.19';
 use Mouse;
 extends 'App::GitGot::Command';
 use 5.010;
+use namespace::autoclean;
 
 use autodie;
 use App::GitGot::Repo::Git;
@@ -11,7 +12,7 @@ use Class::Load       'try_load_class';
 use Cwd;
 use File::Slurp::Tiny 'read_lines';
 
-has 'noclone' => (
+has noclone => (
   is          => 'rw',
   isa         => 'Bool',
   cmd_aliases => 'n',
@@ -100,7 +101,7 @@ App::GitGot::Command::fork - fork a github repo
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 AUTHOR
 
