@@ -1,16 +1,35 @@
 package App::GitGot::Command::list;
+$App::GitGot::Command::list::VERSION = '1.20';
 # ABSTRACT: list managed repositories
-$App::GitGot::Command::list::VERSION = '1.19';
 use Mouse;
 extends 'App::GitGot::Command';
 use 5.010;
+use namespace::autoclean;
+
+use Class::Load       'try_load_class';
 
 sub command_names { qw/ list ls / }
 
+has json => (
+  is            => 'ro',
+  isa           => 'Bool',
+  cmd_aliases   => 'j',
+  traits        => [qw/ Getopt /],
+  documentation => 'stream output as json',
+);
+
 sub _execute {
   my( $self, $opt, $args ) = @_;
 
-  my $max_len = $self->max_length_of_an_active_repo_label;
+  if ( $self->json ) {
+    try_load_class( 'JSON' )
+      or die "json serializing requires the module 'JSON' to be installed\n";
+
+    my @data = map { {%$_}  } $self->active_repos;
+
+    say JSON::to_json( \@data, { pretty => 1 } );
+    return;
+  }
 
   for my $repo ( $self->active_repos ) {
     my $repo_remote = ( $repo->repo and -d $repo->path ) ? $repo->repo
@@ -22,10 +41,12 @@ sub _execute {
 
     if ( $self->quiet ) { say $repo->label }
     else {
-      printf "%-${max_len}s  %-4s  %s\n",
-        $repo->label, $repo->type, $repo_remote;
-      if ( $self->verbose ) {
-        printf "    tags: %s\n" , $repo->tags if $repo->tags;
+      my $max_len = $self->max_length_of_an_active_repo_label;
+
+      printf "%-${max_len}s  %-4s  %s\n", $repo->label, $repo->type, $repo_remote;
+
+      if ( $self->verbose and $repo->tags ) {
+        printf "    tags: %s\n" , $repo->tags
       }
     }
   }
@@ -46,7 +67,7 @@ App::GitGot::Command::list - list managed repositories
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 AUTHOR
 
