@@ -1,16 +1,17 @@
 package App::GitGot::Command::remove;
+$App::GitGot::Command::remove::VERSION = '1.20';
 # ABSTRACT: remove a managed repository from your config
-$App::GitGot::Command::remove::VERSION = '1.19';
 use Mouse;
 extends 'App::GitGot::Command';
 use 5.010;
+use namespace::autoclean;
 
 use List::MoreUtils qw/ any /;
 
-has 'force' => (
-  is          => 'rw',
-  isa         => 'Bool',
-  traits      => [qw/ Getopt /],
+has force => (
+  is     => 'rw',
+  isa    => 'Bool',
+  traits => [qw/ Getopt /],
 );
 
 sub command_names { qw/ remove rm / }
@@ -58,7 +59,7 @@ App::GitGot::Command::remove - remove a managed repository from your config
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 AUTHOR
 
