@@ -1,13 +1,18 @@
 package App::GitGot::Outputter;
+$App::GitGot::Outputter::VERSION = '1.20';
 # ABSTRACT: Generic base class for outputting formatted messages.
-$App::GitGot::Outputter::VERSION = '1.19';
 use Mouse;
 use 5.010;
+use namespace::autoclean;
 
 use Term::ANSIColor;
 
 # boolean indicating whether color messages should be output at all
-has 'no_color' => ( is => 'ro' , isa => 'Bool' , default => 0 );
+has no_color => (
+  is      => 'ro' ,
+  isa     => 'Bool' ,
+  default => 0 ,
+);
 
 
 sub error {
@@ -16,12 +21,6 @@ sub error {
 }
 
 
-sub warning {
-  my( $self , $message ) = @_;
-  return $self->_colored( $message , $self->color_warning );
-}
-
-
 sub major_change {
   my( $self , $message ) = @_;
   return $self->_colored( $message , $self->color_major_change );
@@ -33,6 +32,12 @@ sub minor_change {
   return $self->_colored( $message , $self->color_minor_change );
 }
 
+
+sub warning {
+  my( $self , $message ) = @_;
+  return $self->_colored( $message , $self->color_warning );
+}
+
 sub _colored {
   my( $self , $message , $color_string ) = @_;
 
@@ -55,7 +60,7 @@ App::GitGot::Outputter - Generic base class for outputting formatted messages.
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 METHODS
 
@@ -63,10 +68,6 @@ version 1.19
 
 Display a message using the 'color_error' color settings.
 
-=head2 warning
-
-Display a message using the 'color_warning' color settings.
-
 =head2 major_change
 
 Display a message using the 'color_major_change' color settings.
@@ -75,6 +76,10 @@ Display a message using the 'color_major_change' color settings.
 
 Display a message using the 'color_minor_change' color settings.
 
+=head2 warning
+
+Display a message using the 'color_warning' color settings.
+
 =head1 AUTHOR
 
 John SJ Anderson <genehack@genehack.org>
