@@ -1,34 +1,35 @@
 package App::GitGot::Outputter::dark;
+$App::GitGot::Outputter::dark::VERSION = '1.20';
 # ABSTRACT: Color scheme appropriate for dark terminal backgrounds
-$App::GitGot::Outputter::dark::VERSION = '1.19';
 use Mouse;
 extends 'App::GitGot::Outputter';
 use 5.010;
+use namespace::autoclean;
 
-has 'color_error' => (
+has color_error => (
   is      => 'ro' ,
   isa     => 'Str' ,
   default => 'bold white on_red'
 );
 
-has 'color_warning' => (
-  is      => 'ro' ,
-  isa     => 'Str' ,
-  default => 'bold black on_yellow'
-);
-
-has 'color_major_change' => (
+has color_major_change => (
   is      => 'ro' ,
   isa     => 'Str' ,
   default => 'bold black on_green'
 );
 
-has 'color_minor_change' => (
+has color_minor_change => (
   is      => 'ro' ,
   isa     => 'Str' ,
   default => 'green'
 );
 
+has color_warning => (
+  is      => 'ro' ,
+  isa     => 'Str' ,
+  default => 'bold black on_yellow'
+);
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -44,7 +45,7 @@ App::GitGot::Outputter::dark - Color scheme appropriate for dark terminal backgr
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 AUTHOR
 
