@@ -1,11 +1,12 @@
 package App::GitGot::Outputter::light;
+$App::GitGot::Outputter::light::VERSION = '1.20';
 # ABSTRACT: Color scheme appropriate for dark terminal backgrounds
-$App::GitGot::Outputter::light::VERSION = '1.19';
 use Mouse;
 extends 'App::GitGot::Outputter';
 use 5.010;
+use namespace::autoclean;
 
-has 'color_error' => (
+has color_error => (
   is      => 'ro' ,
   isa     => 'Str' ,
   default => 'bold red'
@@ -14,24 +15,24 @@ has 'color_error' => (
 # Color choices by drdrang based on a conversation that started with
 # <http://www.leancrew.com/all-this/2010/12/batch-comparison-of-git-repositories/>
 
-has 'color_warning' => (
-  is      => 'ro' ,
-  isa     => 'Str' ,
-  default => 'bold magenta'
-);
-
-has 'color_major_change' => (
+has color_major_change => (
   is      => 'ro' ,
   isa     => 'Str' ,
   default => 'blue'
 );
 
-has 'color_minor_change' => (
+has color_minor_change => (
   is      => 'ro' ,
   isa     => 'Str' ,
   default => 'uncolored'
 );
 
+has color_warning => (
+  is      => 'ro' ,
+  isa     => 'Str' ,
+  default => 'bold magenta'
+);
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -47,7 +48,7 @@ App::GitGot::Outputter::light - Color scheme appropriate for dark terminal backg
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 AUTHOR
 
