@@ -1,45 +1,46 @@
 package App::GitGot::Repo;
-$App::GitGot::Repo::VERSION = '1.19';
+$App::GitGot::Repo::VERSION = '1.20';
 # ABSTRACT: Base repository objects
 use Mouse;
 use 5.010;
-
 use namespace::autoclean;
 
-has 'label' => (
+use List::AllUtils qw/ uniq /;
+
+has label => (
   is       => 'ro' ,
   isa      => 'Str' ,
 );
 
-has 'name' => (
+has name => (
   is          => 'ro',
   isa         => 'Str',
   required    => 1 ,
 );
 
-has 'number' => (
+has number => (
   is          => 'ro',
   isa         => 'Int',
   required    => 1 ,
 );
 
-has 'path' => (
+has path => (
   is          => 'ro',
   isa         => 'Str',
   required    => 1 ,
 );
 
-has 'repo' => (
+has repo => (
   is          => 'ro',
   isa         => 'Str',
 );
 
-has 'tags' => (
-  is          => 'ro',
+has tags => (
+  is          => 'rw',
   isa         => 'Str',
 );
 
-has 'type' => (
+has type => (
   is          => 'ro',
   isa         => 'Str',
   required    => 1 ,
@@ -76,6 +77,13 @@ sub BUILDARGS {
 }
 
 
+sub add_tags {
+  my( $self, @tags ) = @_;
+
+  $self->tags( join ' ', uniq sort @tags, split ' ', $self->tags );
+}
+
+
 sub in_writable_format {
   my $self = shift;
 
@@ -92,6 +100,14 @@ sub in_writable_format {
 }
 
 
+sub remove_tags {
+  my( $self, @tags ) = @_;
+
+  %verboten = map { $_ => 1 } @tags;
+
+  $self->tags( join ' ', grep { !$verboten{$_} } split ' ', $self->tags );
+}
+
 __PACKAGE__->meta->make_immutable;
 1;
 
@@ -107,15 +123,25 @@ App::GitGot::Repo - Base repository objects
 
 =head1 VERSION
 
-version 1.19
+version 1.20
 
 =head1 METHODS
 
+=head2 add_tags
+
+Given a list of tags, add them to the current repo object.
+
 =head2 in_writable_format
 
 Returns a serialized representation of the repository for writing out in a
 config file.
 
+=head2 remove_tags
+
+Given a list of tags, remove them from the current repo object.
+
+Passing a tag that is not on the current repo object will silently no-op.
+
 =head1 AUTHOR
 
 John SJ Anderson <genehack@genehack.org>
